@@ -26,14 +26,12 @@ def handler(event, context):
     log.debug(f'Proxying request [{event}]')
     cxn = (HTTPSConnection if _target().scheme == 'https' else HTTPConnection)(_target().hostname, _target().port)
     try:
-        log.debug('Requesting')
         cxn.request(
             'POST', '/lambda',
             JSONEncoder().encode(dict(event=event, context={}, env_vars={k: v for k, v in os.environ.items()
                                                                          if 'AWS_XRAY' not in k})),
             headers={'Content-type': 'application/json'})
 
-        log.debug('Responsing')
         resp = cxn.getresponse()
         if resp.status != 200:
             log.error(f'Response failed: [{resp.status}]')
